@@ -1,20 +1,18 @@
 import pytest
-from aleph_message.models import MessagesResponse
 
-from aleph.sdk.client import AuthenticatedAlephClient
-from tests.integration.toolkit import try_until
+from aleph.sdk.client import AuthenticatedAlephHttpClient
+from aleph.sdk.query.filters import MessageFilter
+from tests.integration.toolkit import has_messages, try_until
 
 from .config import REFERENCE_NODE, TARGET_NODE
 
 
-async def create_message_on_target(
-    fixture_account, emitter_node: str, receiver_node: str
-):
+async def create_message_on_target(account, emitter_node: str, receiver_node: str):
     """
     Create a POST message on the target node, then fetch it from the reference node.
     """
-    async with AuthenticatedAlephClient(
-        account=fixture_account, api_server=emitter_node
+    async with AuthenticatedAlephHttpClient(
+        account=account, api_server=emitter_node
     ) as tx_session:
         post_message, message_status = await tx_session.create_post(
             post_content=None,
@@ -22,17 +20,16 @@ async def create_message_on_target(
             channel="INTEGRATION_TESTS",
         )
 
-    def response_contains_messages(response: MessagesResponse) -> bool:
-        return len(response.messages) > 0
-
-    async with AuthenticatedAlephClient(
-        account=fixture_account, api_server=receiver_node
+    async with AuthenticatedAlephHttpClient(
+        account=account, api_server=receiver_node
     ) as rx_session:
         responses = await try_until(
             rx_session.get_messages,
-            response_contains_messages,
+            has_messages,
             timeout=5,
-            hashes=[post_message.item_hash],
+            message_filter=MessageFilter(
+                hashes=[post_message.item_hash],
+            ),
         )
 
     message_from_target = responses.messages[0]
